.. _trove-install:

Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
Database service, code-named trove, on the controller node.

This section assumes that you already have a working OpenStack
environment with at least the following components installed:
Compute, Image Service, Identity.

* If you want to do backup and restore, you also need Object Storage.

* If you want to provision datastores on block-storage volumes, you also
  need Block Storage.

Note that installation and configuration vary by distribution.

.. toctree::

   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
